// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KSANECORE_VERSION_H
#define KSANECORE_VERSION_H

#define KSANECORE_VERSION_STRING "23.08.5"
#define KSANECORE_VERSION_MAJOR 23
#define KSANECORE_VERSION_MINOR 8
#define KSANECORE_VERSION_PATCH 5
#define KSANECORE_VERSION ((23<<16)|(8<<8)|(5))

#endif
